import {Component, OnInit, ViewChild} from '@angular/core';
import {NzMessageService} from 'ng-zorro-antd';
import {Router} from '@angular/router';
import {DatePipe} from '@angular/common';
import {InfomationService} from '../infomation.service';
import {UploadComponent} from '../../work/modal/upload/upload.component';
import {pageSize} from '../../app.constants';
import {CommonService} from '../../shared/common/common.service';
import {asset_type} from '../information.constans';
import {UploadAssetComponent} from '../modal/upload-asset/upload-asset.component';

@Component({
    selector: 'smart-asset-manage',
    templateUrl: './asset-manage.component.html',
    styles: []
})
export class AssetManageComponent implements OnInit {
    @ViewChild('smartUploadAsset') smartUploadAsset: UploadAssetComponent;

    allChecked = false;
    disabledButton = true;
    indeterminate = false;

    dataSet;
    typeList = asset_type;

    isLoading = false;
    pageCount = pageSize;
    pageNum = 1;
    totalNum;
    isDownload;

    obj = {
        pageCount: null,
        pageNum: null,
        type: null,
        no: null,
        name: null,
        attributionProject: '',
        contacts: '',
    };

    constructor(private infoSer: InfomationService, private message: NzMessageService,
                private router: Router, private commonSer: CommonService, private datePipe: DatePipe) {
    }

    ngOnInit() {
        this.getList();
    }

    checkAll(value: boolean): void {
        this.dataSet.forEach(data => data.checked = value);
        this.refreshStatus();
    }

    refreshStatus(): void {
        const allChecked = this.dataSet.every(value => value.checked === true);
        const allUnChecked = this.dataSet.every(value => !value.checked);
        this.allChecked = allChecked;
        this.indeterminate = (!allChecked) && (!allUnChecked);
        this.disabledButton = !this.dataSet.some(value => value.checked);
    }

    //获取列表
    getList() {
        this.isLoading = true;
        const obj = {
            pageCount: this.pageCount,
            pageNum: this.pageNum,
            type: this.obj.type,
        };
        this.infoSer.propertyPage(obj).subscribe(
            (res) => {
                if (res.errCode == 10000) {
                    this.dataSet = res.data.data;
                    this.totalNum = res.data.totalNum;
                    this.isLoading = false;
                }
            }
        );
    }

    //翻页
    change(e) {
        this.pageNum = e;
        this.getList();
    }

    //查看详情
    lookEvent(item) {
        this.router.navigate(['app/main/handleDetail'], {
            queryParams: {
                eventId: item.id
            }
        });
    }

    //处理事件
    goToHandle(item) {
        this.router.navigate(['app/main/handleEvent'], {
            queryParams: {
                eventId: item.id
            }
        });
    }

    //新增事件
    showAddModal() {
        // this.smartEvent.showAddModal('新增事件');
    }

    //编辑事件
    showEditModal(item) {
        // this.smartEvent.showEditModal('编辑事件', item.id);
    }

    //删除资产
    deleteHandle(data) {
        const arr = {
            ids: []
        };
        arr.ids.push(data.id);
        this.commonSer.confirmThing('删除', '确定删除该资产', () => {
            this.infoSer.propertyDelete(arr).subscribe(
                (res) => {
                  if (res.errCode == 10000) {
                    this.message.success('删除成功');
                    this.getList();
                  }
                }
            );
        });
    }

    //转派
    showTransforModal(item) {
        // this.smartTransfor.showTransforModal('事件转派', item.id);
    }

    //搜索
    search() {
        this.pageNum = 1;
        this.getList();
    }

    //上传资产
    showUploadModal() {
        this.smartUploadAsset.showModal('导入资产');
    }

    //导出资产
    downLoad() {
        this.isDownload = true;
        this.infoSer.propertyExport().subscribe(
            (res) => {
                this.isDownload = false;
                this.commonSer.downloadFile("资产管理.xlsx", res);
            }
        );
    }
}
