import {Component, OnInit, ViewChild} from '@angular/core';
import {CostModalComponent} from '../../project-manager/modal/cost-modal/cost-modal.component';
import {opr_cost_type, opr_time_type, project_status} from '../../project-manager/project.constants';
import {pageSize} from '../../app.constants';
import {WorkService} from '../work.service';
import {NzMessageService} from 'ng-zorro-antd';
import {ProjectService} from '../../project-manager/project.service';
import {Router} from '@angular/router';
import {CommonService} from '../../shared/common/common.service';
import {DatePipe} from '@angular/common';

@Component({
  selector: 'smart-inspect-plan-config',
  templateUrl: './inspect-plan-config.component.html',
  styles: []
})
export class InspectPlanConfigComponent implements OnInit {
  @ViewChild('smartCostModal') smartCostModal: CostModalComponent;
  timeFormat = 'yyyy-MM-dd';

  statusList = project_status;
  costType = [{key: null, value: '全部'}, ...opr_cost_type];
  timeType = [{key: null, value: '全部'}, ...opr_time_type];
  time = {
    startTime: '',
    endTime: '',
    type: null
  };

  page = {
    list: [],
    isLoading: false,
    pageCount: pageSize,
    pageNum: 1,
    totalNum: null
  };

  obj = {
    people: '',  //填报人
    name: '',  //费用名称
    type: null,  //费用类型
    startTime: null,  //开始时间
    endTime: null //结束时间
  };

  constructor(private workSer: WorkService, private message: NzMessageService, private projectSer: ProjectService,
              private router: Router, private commonSer: CommonService, private datePipe: DatePipe) {
  }

  ngOnInit() {
    this.getList();
  }

  //获取列表
  getList() {
    this.page.isLoading = true;
    const obj = {
      obj: this.obj,
      pageNum: this.page.pageNum,
      pageCount: this.page.pageCount
    };
    this.projectSer.findPageCost(obj).subscribe(
        (res) => {
          if (res.errCode == 10000) {
            this.page.list = res.data.data;
            this.page.totalNum = res.data.totalNum;
            this.page.isLoading = false;
          }
        }
    );
  }

  //翻页
  change(e) {
    this.page.pageNum = e;
    this.getList();
  }

  changeTimeType() {
    if (this.time.type == '7') return;
    this.obj.startTime = this.commonSer.getTimeByType(this.time.type).startTime;
    this.obj.endTime = this.commonSer.getTimeByType(this.time.type).endTime;
    console.log(this.obj);
    this.page.pageNum = 1;
    this.getList();
  }

  //搜索
  search() {
    this.page.pageNum = 1;
    this.getList();
  }

  handleOpenModal() {
    this.smartCostModal.showAddModal();
  }
}
